@@ -252,6 +252,7 @@ void wxMaxima::DoConsoleAppend(wxString s, int type, bool newLine,
 {
   MathCell* cell;
 
+  s.Replace(wxT("\n"), wxT(""), true);
   if (type == PROMPTT)
     cell = m_MParser.ParseLine(s, TC_PROMPT);
   else if (type == MPROMPTT)
@@ -338,8 +339,8 @@ void wxMaxima::EnterCommand(wxCommandEvent& event)
   wxString input = m_inputLine->GetValue();
   input.Trim();
   input.Trim(false);
-  if (!m_inLispMode && (input.Length() == 0  ||
-                        (input.Last() != ';' && input.Last()!='$')))
+  if (!m_inLispMode &&
+	    (input.Length() == 0  || (input.Last() != ';' && input.Last()!='$')))
     input.Append(';');
   SendMaxima(input);
   m_inputLine->Clear();
@@ -961,7 +962,7 @@ void wxMaxima::FileMenu(wxCommandEvent& event)
 #endif
         wxString cmd(wxT("save(\""));
         cmd.append(file);
-        cmd.append(wxT("\", ALL);"));
+        cmd.append(wxT("\", all);"));
         SendMaxima(cmd);
       }
     }
@@ -1163,15 +1164,15 @@ void wxMaxima::MaximaMenu(wxCommandEvent& event)
     SendMaxima(wxT("values;"));
     break;
   case menu_display:
-    cmd = wxT("if display2d#false then display2d:false else display2d:true;");
+    cmd = wxT("if display2d#false then display2d:false else display2d:true$");
     SendMaxima(cmd, false);
     break;
   case menu_texform:
-    cmd = wxT("tex(") + expr + wxT(");");
+    cmd = wxT("tex(") + expr + wxT(")$");
     SendMaxima(cmd);
     break;
   case menu_time:
-    cmd = wxT("if showtime#false then showtime:false else showtime:all;");
+    cmd = wxT("if showtime#false then showtime:false else showtime:all$");
     SendMaxima(cmd, false);
     break;
   case menu_fun_def:
@@ -2065,6 +2066,11 @@ void wxMaxima::HelpMenu(wxCommandEvent& event)
 #ifndef __WXMSW__
       filename = wxT(PREFIX);
       filename += wxT("/share/wxMaxima/");
+      if (!wxFileExists(filename + wxT("docs.zip")))
+      {
+        filename = wxT(PREFIX);
+        filename += wxT("/share/doc/wxmaxima/");
+      }
 #else
       filename = wxGetCwd() + wxT("\\data\\");
 #endif
@@ -2321,7 +2327,6 @@ BEGIN_EVENT_TABLE(wxMaxima, wxFrame)
   EVT_UPDATE_UI(tb_copy, wxMaxima::UpdateToolBar)
   EVT_UPDATE_UI(tb_delete, wxMaxima::UpdateToolBar)
   EVT_UPDATE_UI(tb_interrupt, wxMaxima::UpdateToolBar)
-//  EVT_UPDATE_UI(menu_selection_to_input, wxMaxima::UpdateMenus)
   EVT_CLOSE(wxMaxima::OnClose)
   EVT_ACTIVATE(wxMaxima::OnActivate)
   EVT_SET_FOCUS(wxMaxima::OnSetFocus)
